@@ -13,7 +13,7 @@ use Time::Piece ();
 
 has 'mysql';
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 sub dequeue {
   my ($self, $worker_id, $wait, $options) = @_;
@@ -84,15 +84,15 @@ sub enqueue {
   # restriction is added after the job itself.
   my $tx = $db->begin;
 
-  $db->query(
+  my $job_id = $db->query(
     "insert into minion_jobs (`args`, `attempts`, `delayed`, `expires`, `lax`, `priority`, `queue`, `task`)
      values (?, ?, (DATE_ADD(NOW(), INTERVAL ? SECOND)), case when ? is not null then date_add( now(), interval ? second ) end, ?, ?, ?, ?)",
      encode_json($args), $options->{attempts} // 1,
      $options->{delay} // 0, ($options->{expire})x2, $options->{lax} ? 1 : 0,
      $options->{priority} // 0, $options->{queue} // 'default', $task,
-  );
-  my $job_id = $db->dbh->{mysql_insertid};
-  if ( my $notes = $options->{notes} ) {
+  )->last_insert_id;
+
+if ( my $notes = $options->{notes} ) {
     $self->_note( $job_id, $notes, $db );
   }
 
@@ -365,9 +365,9 @@ sub register_worker {
   my $sql = q{INSERT INTO minion_workers (id, host, pid, status)
     VALUES (?, ?, ?, ?)
     ON DUPLICATE KEY UPDATE notified=NOW(), host=VALUES(host), pid=VALUES(pid), status=VALUES(status)};
-  $db->query($sql, $id, hostname, $$, encode_json( $options->{status} // {} ) );
+  my $res = $db->query($sql, $id, hostname, $$, encode_json( $options->{status} // {} ) );
 
-  return $id // $db->dbh->{mysql_insertid};
+  return $id // $res->last_insert_id;
 }
 
 sub remove_job {
@@ -1104,7 +1104,7 @@ Minion::Backend::mysql
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
@@ -1526,7 +1526,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexander Nalobin Dmitry Krylov Hu Yin Jason A. Crome Larry Leszczynski Olaf Alders Paul Cochrane Zoffix Znet
+=for stopwords Alexander Nalobin Dmitry Krylov Hu Yin Jason A. Crome Larry Leszczynski Olaf Alders Paul Cochrane Sergey Andreev Zoffix Znet
 
 =over 4
 
@@ -1560,6 +1560,10 @@ Paul Cochrane <paul@liekut.de>
 
 =item *
 
+Sergey Andreev <40195653+saintserge@users.noreply.github.com>
+
+=item *
+
 Zoffix Znet <cpan@zoffix.com>
 
 =back
